==> connector-client-1.0.0-20230323.093001-2-sources.jar: com/daas/nros/connector/model/vo/SingleRetailAddRequestVO.java <==
package com.daas.nros.connector.model.vo;

import com.bizvane.connectorservice.entity.base.BaseModel;
import com.bizvane.connectorservice.entity.common.OrderItemVO;
import lombok.ToString;

import java.util.List;

/**
 * @author admin
 */
@ToString
public class SingleRetailAddRequestVO extends BaseModel {

    private String consignee_province;

    private String consignee_address;

    private String consignee_name;

    private String order_time;

    private String consignee_area;

    private String consignee_city;

    private String consignee_phone;

    private String eordercode;

    private List<com.bizvane.connectorservice.entity.common.OrderItemVO> wx_order_item;


    public String getConsignee_province() {
        return consignee_province;
    }

    public void setConsignee_province(String consignee_province) {
        this.consignee_province = consignee_province;
    }

    public String getConsignee_address() {
        return consignee_address;
    }

    public void setConsignee_address(String consignee_address) {
        this.consignee_address = consignee_address;
    }

    public String getConsignee_name() {
        return consignee_name;
    }

    public void setConsignee_name(String consignee_name) {
        this.consignee_name = consignee_name;
    }

    public String getOrder_time() {
        return order_time;
    }

    public void setOrder_time(String order_time) {
        this.order_time = order_time;
    }

    public String getConsignee_area() {
        return consignee_area;
    }

    public void setConsignee_area(String consignee_area) {
        this.consignee_area = consignee_area;
    }

    public String getConsignee_city() {
        return consignee_city;
    }

    public void setConsignee_city(String consignee_city) {
        this.consignee_city = consignee_city;
    }

    public String getConsignee_phone() {
        return consignee_phone;
    }

    public void setConsignee_phone(String consignee_phone) {
        this.consignee_phone = consignee_phone;
    }

    public String getEordercode() {
        return eordercode;
    }

    public void setEordercode(String eordercode) {
        this.eordercode = eordercode;
    }

    public List<com.bizvane.connectorservice.entity.common.OrderItemVO> getWx_order_item() {
        return wx_order_item;
    }

    public void setWx_order_item(List<OrderItemVO> wx_order_item) {
        this.wx_order_item = wx_order_item;
    }
}

==> connector-client-1.0.0-20230324.090846-5-sources.jar: com/daas/nros/connector/model/vo/SingleRetailAddRequestVO.java <==
package com.daas.nros.connector.model.vo;

import com.daas.nros.connector.model.base.BaseModel;

import lombok.ToString;

import java.util.List;

/**
 * @author admin
 */
@ToString
public class SingleRetailAddRequestVO extends BaseModel {

    private String consignee_province;

    private String consignee_address;

    private String consignee_name;

    private String order_time;

    private String consignee_area;

    private String consignee_city;

    private String consignee_phone;

    private String eordercode;

    private List<OrderItemVO> wx_order_item;


    public String getConsignee_province() {
        return consignee_province;
    }

    public void setConsignee_province(String consignee_province) {
        this.consignee_province = consignee_province;
    }

    public String getConsignee_address() {
        return consignee_address;
    }

    public void setConsignee_address(String consignee_address) {
        this.consignee_address = consignee_address;
    }

    public String getConsignee_name() {
        return consignee_name;
    }

    public void setConsignee_name(String consignee_name) {
        this.consignee_name = consignee_name;
    }

    public String getOrder_time() {
        return order_time;
    }

    public void setOrder_time(String order_time) {
        this.order_time = order_time;
    }

    public String getConsignee_area() {
        return consignee_area;
    }

    public void setConsignee_area(String consignee_area) {
        this.consignee_area = consignee_area;
    }

    public String getConsignee_city() {
        return consignee_city;
    }

    public void setConsignee_city(String consignee_city) {
        this.consignee_city = consignee_city;
    }

    public String getConsignee_phone() {
        return consignee_phone;
    }

    public void setConsignee_phone(String consignee_phone) {
        this.consignee_phone = consignee_phone;
    }

    public String getEordercode() {
        return eordercode;
    }

    public void setEordercode(String eordercode) {
        this.eordercode = eordercode;
    }

    public List<OrderItemVO> getWx_order_item() {
        return wx_order_item;
    }

    public void setWx_order_item(List<OrderItemVO> wx_order_item) {
        this.wx_order_item = wx_order_item;
    }
}
